/*
Circuit de test : clignotant  LED
(C) Fabrice Sincre, avril 2010
Lyce Jules Algoud (Valence)
Version 1.0.0
Microcontrleur PIC 16F876A
Langage C : compilateur mikroC v8.2

Bits de configuration : 0x3F73
    _RC_OSC : oscillateur RC (0.00213 MHz)
	_WDT_OFF : watchdog timer OFF
	_PWRTE_ON : power up timer ON
	_BODEN_ON : brown out detect ON
	_LVP_OFF : low voltage program OFF
*/

# define BIT_LED   F1

void interrupt()
{
     // routine d'interruption
     // 1 seule source d'interruption : TMR0 en mode timer
     // toutes les 256*1 = 256 cycles (prescaler 1:1)

    if ((INTCON.T0IE) && (INTCON.T0IF))
    {
		PORTA.BIT_LED = ~PORTA.BIT_LED;
			// on inverse le niveau logique de la sortie RA1
			// => inversion de l'tat de la LED
       
		INTCON.T0IF = 0; //on efface le drapeau du timer TMR0
    }
}

void main()
{
     // initialisation

	OPTION_REG = 0b11011111;
		// bit 5 (T0CS) = 0 : TMR0 en mode timer
		// prescaler 1:1
  
	ADCON1 = 0b00000110; // la broche RA1 est configure commme entre/sortie numrique

	TRISA = 0b11111101;  // bit 1 du port A (RA1) = 0 : configuration en sortie (commande de la LED)

	PORTA.BIT_LED = 0 ;  // Led allume

	INTCON = 0b10100000;
		// bit 7 (GIE) = 1 : autorisation globale des interruptions
		// bit 5 (T0IE) = 1 : autorisation de l'interruption TMR0
		// bit 2 (T0IF)= 0 : on efface le drapeau de l'interruption TMR0
  
	do
	{
		// on attend le dbordement de TMR0 (0xFF -> 0x00)
		// ce qui gnre une interruption
	} while(1);
}
